Adjust the values in the new :file:`settings.py` file to your liking. You will
need to provide at least the database credentials and Django secret key, but
you will want more changes for production setup, see :ref:`configuration`.
